#!/bin/sh

set -u

#ConfPath: auth.conf, engine.conf, persistent.conf, terminal.conf version. Also product.conf if ProductConfPath is not set.
ConfPath="/data/data/com.lightwan.AcceleratorUI"
#ProductConfPath: product.conf
ProductConfPath=""
#WorkPath: lightwan, dispatch, lightwan.sh
WorkPath="/data/data/com.lightwan.AcceleratorUI"
#PcapPath: packet capture path, leave it blank for default path
PcapPath=""
logPath=""
logName="lightwan_sh.log"
version=""

DefaultIf=eth0
action="start"
videoPortRange="50000:50105"
probePortRange="50151:50200"
accePort="18000"
Mode=0
retryCnt=10
shouldHandleRule=1
status=""
ip6Enable=0

#Exit Error Code
ER_tun99_exist=1
ER_product_conf_not_exit=2
ER_add_rule_fail=3
ER_lightwan_start_fail=4
ER_probe_lightwan_fail=5
ER_acce_add_rule_fail=6
ER_video_add_rule_fail=7
ER_lightwan_not_start=8
ER_dispatch_not_exit=9
ER_dispatch_set_fail=10
ER_missing_conf_files=11
ER_lightwan_not_exist=12
#ER_lightwan_not_started=255

usage()
{
    echo "-t [interface name], custom output interface"
}

get_log_path()
{
    logPathRoot=`cat ${ProductConfPath}/product.conf | grep LogPath`
    if [ -n ${logPathRoot} ]; then
        logPath=${logPathRoot#*=}"/"${logName}
    fi
}

logcat() #info
{
    get_log_path
    if [ -n ${logPath} ]; then
        echo "$(date) $version lightwan_sh $status ${@}" >>${logPath}
    else
        echo "$(date) $version lightwan_sh $status ${@}"
    fi
}

log_exit() #cmd #errno #details
{
    logcat "${1} exit $2 $3"
    echo "${1} exit $2 info: $3"
    if [ ${status} == "[Start]" ];then
        lightwan_stop ${videoPortRange} ${probePortRange} ${accePort}
    fi
    exit ${2}
    }

check_ip6_exist()
{
   ip6tables -L > /dev/null 2>&1 && {
        ip6Enable=1
    }
}

init_path()
{
    if [ -e $WorkPath ]; then
        if [ -e "${WorkPath}/lightwan" ]; then
            if [ ! -x "${WorkPath}/lightwan" ];then
                chmod 751 ${WorkPath}/lightwan
            fi
        else
            err_msg="Could not find lightwan in $WorkPath"
            log_exit "lightwan not exist" $ER_lightwan_not_exist "${err_msg}"
        fi
        if [ -e "${WorkPath}/dispatch" ]; then
            if [ ! -x "${WorkPath}/dispatch" ];then
                chmod 751 ${WorkPath}/dispatch
            fi
        else
            err_msg="Could not find dispatch in $WorkPath"
            log_exit "dispatch not exist" $ER_dispatch_not_exit "${err_msg}"
        fi
    fi

    if [ ! -f $ConfPath/auth.conf -o ! -f $ConfPath/engine.conf ];then
        err_msg="Could not find auth.conf engine.conf in $ConfPath"
        log_exit "missing conf files" $ER_missing_conf_files "${err_msg}"
    fi

    if [ ! -n "$ProductConfPath" ];then
        ProductConfPath=$ConfPath
    fi

    if [ ! -f ${ProductConfPath}/product.conf ];then
        err_msg="Could not find product.conf in $ProductConfPath"
        log_exit "product.conf does not exist" $ER_product_conf_not_exit "${err_msg}"
    fi

    if [ -f ${ConfPath}/version ];then
        version=`cat ${ConfPath}/version`
    fi
}

probe_peristent_rule_set() #probePortRange
{
    local probe_port_range=${1}

    local cmd="iptables -t mangle -A INPUT -m mark ! --mark 999 -p udp --dport ${probe_port_range} -j lightwan_in"
    local details="failed to add probe-related lightwan_in rules to iptables! script execution interrupted and exited."
    ${cmd} || log_exit "${cmd}" $ER_probe_lightwan_fail "${details}"
    logcat ${cmd}
    
    cmd="iptables -t mangle -A OUTPUT -m mark ! --mark 999 -p udp --sport ${probe_port_range} -j lightwan_out"
    details="failed to add probe-related lightwan_out rules to iptables! script execution interrupted and exited."
    ${cmd} || log_exit "${cmd}" $ER_probe_lightwan_fail "${details}"
    logcat ${cmd}

    [ $ip6Enable -eq 1 ] && {
        cmd="ip6tables -t mangle -A INPUT -m mark ! --mark 999 -p udp --dport ${probe_port_range} -j lightwan_in"
        details="failed to add probe-related lightwan_in rules to ip6tables! script execution interrupted and exited."
        ${cmd} || log_exit "${cmd}" $ER_probe_lightwan_fail "${details}"
        logcat ${cmd}

        cmd="ip6tables -t mangle -A OUTPUT -m mark ! --mark 999 -p udp --sport ${probe_port_range} -j lightwan_out"
        details="failed to add probe-related lightwan_out rules to ip6tables! script execution interrupted and exited."
        ${cmd} || log_exit "${cmd}" $ER_probe_lightwan_fail "${details}"
        logcat ${cmd}
    }
}

probe_peristent_rule_clear() #probePortRange
{
    local probe_port_range=${1}
    local check=`iptables -t mangle -L INPUT|grep lightwan_in |grep ${probe_port_range}`
    while [ -n "$check" ]
    do
        local cmd="iptables -t mangle -D INPUT -m mark ! --mark 999 -p udp --dport ${probe_port_range} -j lightwan_in"
        ${cmd}
        logcat "$cmd $?"
        check=`iptables -t mangle -L INPUT|grep lightwan_in |grep ${probe_port_range}`
    done

    check=`iptables -t mangle -L OUTPUT|grep lightwan_out |grep ${probe_port_range}`
    while [ -n "$check" ]
    do
        cmd="iptables -t mangle -D OUTPUT -m mark ! --mark 999 -p udp --sport ${probe_port_range} -j lightwan_out"
        ${cmd}
        logcat "${cmd} $?"
        check=`iptables -t mangle -L OUTPUT|grep lightwan_out |grep ${probe_port_range}`
    done

    [ $ip6Enable -eq 1 ] && {
        check=`ip6tables -t mangle -L INPUT|grep lightwan_in |grep ${probe_port_range}`
        while [ -n "$check" ]
        do
            cmd="ip6tables -t mangle -D INPUT -m mark ! --mark 999 -p udp --dport ${probe_port_range} -j lightwan_in"
            ${cmd}
            logcat "$cmd $?"
            check=`ip6tables -t mangle -L INPUT|grep lightwan_in |grep ${probe_port_range}`
        done

        check=`ip6tables -t mangle -L OUTPUT|grep lightwan_out |grep ${probe_port_range}`
        while [ -n "$check" ]
        do
            cmd="ip6tables -t mangle -D OUTPUT -m mark ! --mark 999 -p udp --sport ${probe_port_range} -j lightwan_out"
            ${cmd}
            logcat "${cmd} $?"
            check=`ip6tables -t mangle -L OUTPUT|grep lightwan_out |grep ${probe_port_range}`
        done
    }
}

acce_tcp_rule_clear()
{
    local all_add_tcp_rules=`iptables -t mangle -L INPUT|grep lightwan_in |grep tcp`
    local related_tcp_port=`echo $all_add_tcp_rules| awk '{split($0,a,"[:l]");print a[3]}'`
    while [ -n "$related_tcp_port" ]
    do
        local cmd="iptables -t mangle -D INPUT -m mark ! --mark 999 -p tcp --dport ${related_tcp_port} -j lightwan_in"
        ${cmd}
        logcat "${cmd} $?"
        all_add_tcp_rules=`iptables -t mangle -L INPUT|grep lightwan_in |grep tcp`
        related_tcp_port=`echo $all_add_tcp_rules| awk '{split($0,a,"[:l]");print a[3]}'`  
    done

    [ $ip6Enable -eq 1 ] && {
        all_add_tcp_rules=`ip6tables -t mangle -L INPUT|grep lightwan_in |grep tcp`
        related_tcp_port=`echo $all_add_tcp_rules| awk '{split($0,a,"[:l]");print a[3]}'`
        while [ -n "$related_tcp_port" ]
        do
            cmd="ip6tables -t mangle -D INPUT -m mark ! --mark 999 -p tcp --dport ${related_tcp_port} -j lightwan_in"
            ${cmd}
            logcat "${cmd} $?"
            all_add_tcp_rules=`ip6tables -t mangle -L INPUT|grep lightwan_in |grep tcp`
            related_tcp_port=`echo $all_add_tcp_rules| awk '{split($0,a,"[:l]");print a[3]}'`  
        done
    }
}

acce_persistent_rule_clear() #probePortRange
{
    local probe_port_range=${1}

    probe_peristent_rule_clear ${probe_port_range}
    acce_tcp_rule_clear
}

acce_persistent_rule_add() #probePortRange
{
    local probe_port_range=${1}
    local acce_port=${accePort}
 
    probe_peristent_rule_set $1

    local cmd="iptables -t mangle -A INPUT -m mark ! --mark 999 -p tcp --dport ${acce_port} -j lightwan_in"
    local details="failed to add acce-related lightwan_in rules to iptables! script execution interrupted and exited."
    ${cmd} || log_exit "${cmd}" $ER_acce_add_rule_fail "${details}"
    logcat ${cmd}

    [ $ip6Enable -eq 1 ] && {
        cmd="ip6tables -t mangle -A INPUT -m mark ! --mark 999 -p tcp --dport ${acce_port} -j lightwan_in"
        details="failed to add acce-related lightwan_in rules to ip6tables! script execution interrupted and exited."
        ${cmd} || log_exit "${cmd}" $ER_acce_add_rule_fail "${details}"
        logcat ${cmd}
    }
}

video_acce_del() #videoPortRange
{
    local video_port_range=${1}    
    
    local check=`iptables -t mangle -L INPUT|grep lightwan_in |grep ${video_port_range}`
    while [ -n "$check" ]
    do
        local cmd="iptables -t mangle -D INPUT -m mark ! --mark 999 -p udp --dport ${video_port_range} -j lightwan_in"
        ${cmd} 2>/dev/null
        logcat "${cmd} $?"
        check=`iptables -t mangle -L INPUT|grep lightwan_in |grep ${video_port_range}`
    done
    
    check=`iptables -t mangle -L OUTPUT|grep lightwan_out |grep ${video_port_range}`
    while [ -n "$check" ]
    do
        cmd="iptables -t mangle -D OUTPUT -m mark ! --mark 999 -p udp --sport ${video_port_range} -j lightwan_out"
        ${cmd} 2>/dev/null
        logcat "${cmd} $?"
        check=`iptables -t mangle -L OUTPUT|grep lightwan_out |grep ${video_port_range}`
    done

    [ $ip6Enable -eq 1 ] && {
        check=`ip6tables -t mangle -L INPUT|grep lightwan_in |grep ${video_port_range}`
        while [ -n "$check" ]
        do
            cmd="ip6tables -t mangle -D INPUT -m mark ! --mark 999 -p udp --dport ${video_port_range} -j lightwan_in"
            ${cmd} 2>/dev/null
            logcat "${cmd} $?"
            check=`ip6tables -t mangle -L INPUT|grep lightwan_in |grep ${video_port_range}`
        done
        
        check=`ip6tables -t mangle -L OUTPUT|grep lightwan_out |grep ${video_port_range}`
        while [ -n "$check" ]
        do
            cmd="ip6tables -t mangle -D OUTPUT -m mark ! --mark 999 -p udp --sport ${video_port_range} -j lightwan_out"
            ${cmd} 2>/dev/null
            logcat "${cmd} $?"
            check=`ip6tables -t mangle -L OUTPUT|grep lightwan_out |grep ${video_port_range}`
        done
    }
}

video_acce_safe_add() #videoPortRange
{
    local video_port_range=${1}    

    video_acce_del ${video_port_range}
    
    local cmd="iptables -t mangle -A INPUT -m mark ! --mark 999 -p udp --dport ${video_port_range} -j lightwan_in"
    local details="failed to add video-related lightwan_in rules to iptables! script execution interrupted and exited."
    ${cmd} || log_exit "${cmd}" $ER_video_add_rule_fail "${details}"
    logcat ${cmd}

    cmd="iptables -t mangle -A OUTPUT -m mark ! --mark 999 -p udp --sport ${video_port_range} -j lightwan_out"
    details="failed to add video-related lightwan_out rules to iptables! script execution interrupted and exited."
    ${cmd} || log_exit "${cmd}" $ER_video_add_rule_fail "${details}"
    logcat ${cmd}

    [ $ip6Enable -eq 1 ] && {
        cmd="ip6tables -t mangle -A INPUT -m mark ! --mark 999 -p udp --dport ${video_port_range} -j lightwan_in"
        details="failed to add video-related lightwan_in rules to ip6tables! script execution interrupted and exited."
        ${cmd} || log_exit "${cmd}" $ER_video_add_rule_fail "${details}"
        logcat ${cmd}

        cmd="ip6tables -t mangle -A OUTPUT -m mark ! --mark 999 -p udp --sport ${video_port_range} -j lightwan_out"
        details="failed to add video-related lightwan_out rules to ip6tables! script execution interrupted and exited."
        ${cmd} || log_exit "${cmd}" $ER_video_add_rule_fail "${details}"
        logcat ${cmd}
    }
}

ip_rule_safe_del()
{
    local continue_exe=true
    while ${continue_exe}
    do
        ip rule del fwmark 0x3e7 2>/dev/null || continue_exe=false
    done
    logcat "ip rule del fwmark 0x3e7 0"

    [ $ip6Enable -eq 1 ] && {
        continue_exe=true
        while ${continue_exe}
        do
            ip -6 rule del fwmark 0x3e7 2>/dev/null || continue_exe=false
        done
        logcat "ip -6 rule del fwmark 0x3e7 0"
    }
}

ip_rule_safe_add() #acceIf
{
    ip_rule_safe_del
    
    IsNeedConfigIpRule=`cat ${ProductConfPath}/product.conf|grep IsNeedConfigIpRule`
    is_need_config_ip_rule=${IsNeedConfigIpRule#*=}
    #special devices do not need ip rule 999, shouldHandleRule to 0, default to 1.
    case ${is_need_config_ip_rule} in
    "FALSE"|"false") let shouldHandleRule=0;;
    *) let shouldHandleRule=1;;
    esac

    if [ $shouldHandleRule -eq 1 ]; then
        local retryNum=$retryCnt
        while [ $retryNum -gt 0 ]
        do
            ip rule add fwmark 0x3e7 lookup ${1} pref 999
            local result=`ip rule show | grep 999`
            if [ ! -n "$result" ];then
                echo "failed to add ip rule , retrying"
                retryNum=$(($retryNum-1))
                if [ $retryNum -eq 0 ];then
                    details="failed to add rules to ip rule! script execution interrupted and exited."
                    log_exit "ip rule add fwmark 0x3e7 lookup ${1} pref 999 failed" $ER_add_rule_fail "${details}"
                fi
                sleep 1
            else
                retryNum=0
            fi
        done
        logcat "ip rule add fwmark 0x3e7 lookup ${1} pref 999 success"

        [ $ip6Enable -eq 1 ] && {
            retryNum=$retryCnt
            while [ $retryNum -gt 0 ]
            do
                ip -6 rule add fwmark 0x3e7 lookup ${1} pref 999
                local result=`ip -6 rule show | grep 999`
                if [ ! -n "$result" ];then
                    echo "failed to add ip -6 rule , retrying"
                    retryNum=$(($retryNum-1))
                    if [ $retryNum -eq 0 ];then
                        details="failed to add rules to ip -6 rule! script execution interrupted and exited."
                        log_exit "ip -6 rule add fwmark 0x3e7 lookup ${1} pref 999 failed" $ER_add_rule_fail "${details}"
                    fi
                    sleep 1
                else
                    retryNum=0
                fi
            done
            logcat "ip -6 rule add fwmark 0x3e7 lookup ${1} pref 999 success"
        }
    fi
}

check_start_conditions()
{
    tun99_exist=`ifconfig|grep -ci "tun99"`
    if [ $tun99_exist -ne 0 ];then
        err_msg="failed to start lightwan, tun99 is required, but it is occupied. 
        maybe you can run lightwan.sh stop and restart."
        log_exit "tun99 occupied" $ER_tun99_exist "${err_msg}"
    fi
}

dispatch_ltt_port() #accePort
{ 
    local acce_port=${1}
    local cnt=5
    while [ $cnt -gt 0 ]
    do
        ${WorkPath}/dispatch set_appex_cmd/"engine=0 lttPort: ${acce_port}" >/dev/null 2>&1
        ${WorkPath}/dispatch set_ltt_cmd/"lttv1_port: ${acce_port}" >/dev/null 2>&1
        ltt_port=`${WorkPath}/dispatch get_appex_cmd/"engine=0"|grep lttPort | cut -d " " -f 2 2>/dev/null`
        lttv1_port=`${WorkPath}/dispatch get_ltt_cmd |grep lttv1_port | cut -d " " -f 2 2>/dev/null`
        if [ -n "${ltt_port}" -a -n "${lttv1_port}" ];then
            if [ "${ltt_port}" == "${acce_port}" -a "${lttv1_port}" == "${acce_port}" ];then
                echo "success to set ltt port."
                return 1
            else
                echo "failed to set ltt port, maybe engine have not got the param. retrying..."
                sleep 1
            fi
        else
            echo "failed to set ltt port, maybe engine have not got the param. retrying..."
            sleep 1
        fi
        cnt=$(($cnt-1))
        if [ $cnt -eq 0 ];then
            log_exit "failed to set ltt port, please check dispatch version!" $ER_dispatch_set_fail "failed to set ltt port, please check dispatch version! script execution interrupted and exited."
        fi
    done
}

lightwan_start() #videoPortRange #probePortRange #acceif
{
     #for sip monitor process
    #clean the sip in auth.conf, ready to get the new one
    if [ `grep -c -i "Sip=" "$ConfPath/auth.conf"` -ne '0' ];then
        busybox sed -i '/Sip=/d' "$ConfPath/auth.conf"
    fi

    local sipmonitor=`grep -c -i "IsNeedSipMonitor=TRUE" "$ProductConfPath/product.conf"`
    if [ $sipmonitor -ne '0' ];then
        logcat "start lightwan_sipmonitor process"
        $WorkPath/lightwan -M start & >/dev/null
    fi
    
    check_start_conditions
    local video_port_range=${1}
    local probe_port_range=${2}
    local acce_interface=${3}
    local start_args=""

    ip_rule_safe_add ${acce_interface}
    sleep 1

    start_args="-p ${ConfPath} -e -m ${Mode} -P $ProductConfPath"
    #run cpe
    logcat "cmd lightwan start ${start_args}"
    $WorkPath/lightwan ${start_args} || {
        lightwan_stop ${videoPortRange} ${probePortRange}
        log_exit "lightwan start failed" $ER_lightwan_start_fail "lightwan start failed, because something wrong with lightwan file"
    }
    logcat "lightwan ${start_args} success"

    sleep 8 
    #clear
    iptables -t mangle -D INPUT -m mark ! --mark 999 -j lightwan_in 2>/dev/null
    logcat "iptables -t mangle -D INPUT -m mark ! --mark 999 -j lightwan_in 2>/dev/null clear $?"
    iptables -t mangle -D OUTPUT -m mark ! --mark 999 -j lightwan_out 2>/dev/null
    logcat "iptables -t mangle -D OUTPUT -m mark ! --mark 999 -j lightwan_out 2>/dev/null clear $?"

    [ $ip6Enable -eq 1 ] && {
        ip6tables -t mangle -D INPUT -m mark ! --mark 999 -j lightwan_in 2>/dev/null
        logcat "ip6tables -t mangle -D INPUT -m mark ! --mark 999 -j lightwan_in 2>/dev/null clear $?"
        ip6tables -t mangle -D OUTPUT -m mark ! --mark 999 -j lightwan_out 2>/dev/null
        logcat "ip6tables -t mangle -D OUTPUT -m mark ! --mark 999 -j lightwan_out 2>/dev/null clear $?"
    }

    acce_persistent_rule_add ${probe_port_range}
    video_acce_safe_add ${video_port_range}
    dispatch_ltt_port ${accePort}
    if [ -n "$PcapPath" ];then
        ${WorkPath}/dispatch set_pcap_dir/"$PcapPath" >/dev/null 2>&1
        if [ $? -ne 0 ];then
            echo "Warning: failed to set pcap dir ${PcapPath}."
            logcat "Warning: failed to set pcap dir ${PcapPath}."
        else
            echo "success to set pcap dir ${PcapPath}."
            logcat "set pcap dir ${PcapPath} success"
        fi
    fi
    logcat "cmd lightwan start completed 0"
    echo "cmd lightwan start completed 0"
}

lightwan_stop() #videoPortRange #probePortRange
{
    logcat "cmd lightwan_sipmonitor stop"
    ${WorkPath}/lightwan -M stop >/dev/null

    local video_port_range=${1}
    local probe_port_range=${2}

    logcat "cmd lightwan stop ${1} ${2}"

    video_acce_del ${video_port_range}
    acce_persistent_rule_clear ${probe_port_range} 

    cmd="iptables -X lightwan_in -t mangle"
    ${cmd} 2>/dev/null
    logcat "${cmd} $?"
    _cmd="iptables -X lightwan_out -t mangle"
    ${_cmd} 2>/dev/null
    logcat "${_cmd} $?"

    [ $ip6Enable -eq 1 ] && {
        cmd="ip6tables -X lightwan_in -t mangle"
        ${cmd} 2>/dev/null
        logcat "${cmd} $?"
        _cmd="ip6tables -X lightwan_out -t mangle"
        ${_cmd} 2>/dev/null
        logcat "${_cmd} $?"
    }

    ip_rule_safe_del
    
    ${WorkPath}/lightwan -D quit 2>/dev/null
    
    stop_ret=$?
    logcat "${WorkPath}/lightwan quit $stop_ret"
    sleep 3
    if [ $stop_ret -eq 0 ];then
        echo "cmd lightwan stop completed $stop_ret"
    else
        echo "cmd lightwan stop failed with error code: $stop_ret"
    fi
    exit $stop_ret
}

lightwan_update()
{
    #clear old rule first
    acce_tcp_rule_clear
    local lightwan_already_start=`ps -ef |grep -w lightwan_healthd|grep -v grep`
    if [ -z "${lightwan_already_start}" ];then
        log_exit "failed to update, lightwan has not been started" $ER_lightwan_not_start "failed to update, lightwan has not been started, you should start lightwan first"
    fi
    
    dispatch_ltt_port ${accePort}
    local ret=`echo $?`
    if [ $ret -eq 1 ];then
        local check=`iptables -t mangle -L INPUT|grep lightwan_in |grep ${probePortRange}`
        if [ -z "${check}" ];then
            acce_persistent_rule_add ${probePortRange}
        else
            local cmd="iptables -t mangle -A INPUT -m mark ! --mark 999 -p tcp --dport ${accePort} -j lightwan_in"
            local details="failed to add acce-related lightwan_in rules to iptables! script execution interrupted and exited."
            ${cmd} || log_exit "${cmd}" $ER_acce_add_rule_fail "${details}"
            logcat ${cmd}

            [ $ip6Enable -eq 1 ] && {
                cmd="ip6tables -t mangle -A INPUT -m mark ! --mark 999 -p tcp --dport ${accePort} -j lightwan_in"
                details="failed to add acce-related lightwan_in rules to ip6tables! script execution interrupted and exited."
                ${cmd} || log_exit "${cmd}" $ER_acce_add_rule_fail "${details}"
                logcat ${cmd}
            }
        fi
    fi
}

lightwan_video_acce_enable() #videoPortRange
{
    local video_port_range=${1}

    video_acce_safe_add ${video_port_range}
}

lightwan_video_acce_disable() #videoPortRange
{
    local video_port_range=${1}
    video_acce_del ${video_port_range}
}

show_version()
{
    if [ -f ${ConfPath}/version ];then
        version=`cat ${ConfPath}/version`
    else
        version="version file not found"
    fi
    echo $version
}

lightwan_acce_interface_update() #DefaultIf
{
    local acce_interface=${1}
    
    ip_rule_safe_del
    ip_rule_safe_add ${acce_interface}
}

for opt in ${@};
do
    str="="
    result=$(echo $opt | grep "$str")
    if [ -n $result ]; then
        k=${opt%=*}
        v=${opt#*=}
    else
        k=${opt} 
    fi

    case ${k} in
        "start") action="start";;
        "stop")  action="stop";;
        "update") action="update";;
        "--version"|"-v") action="show_lightwan_version";;
        "video_acce_disable") action="video_acce_disable";;
        "video_acce_enable") action="video_acce_enable";;
        "acce_interface_update") action="acce_interface_update";;
        "--mode"|"-m") Mode=${v};;
        "--interface"|"-i") DefaultIf=${v};;
        "--video_port_range"|"-apr") videoPortRange=${v};; 
        "--probe_port_range"|"-ppr") probePortRange=${v};;
        "--acce_port"|"-ap") accePort=${v};;
        "--conf_path"|"-cp") ConfPath=${v};;
        "--product_conf_path"|"-pcp") ProductConfPath=${v};;
        "--work_path"|"-wp") WorkPath=${v};;
        "--pcap_path"|"-pcap") PcapPath=${v};;
        "--retry_times"|"-rt") retryCnt=${v};;
        *) echo "${opt} is error";;
    esac
done

init_path
check_ip6_exist

if [ ${action} = "start" ]; then
    status="[Start]"
    lightwan_start ${videoPortRange} ${probePortRange} ${DefaultIf}
elif [ ${action} = "stop" ]; then
    status="[Stop]"
    lightwan_stop ${videoPortRange} ${probePortRange} 
elif [ ${action} = "update" ];then
    status="[Update]"
    lightwan_update
elif [ ${action} = "show_lightwan_version" ];then
    status="[Version]"
    show_version
elif [ ${action} = "video_acce_enable" ]; then
    status="[Enable Acce]"
    lightwan_video_acce_enable ${videoPortRange}
elif [ ${action} = "video_acce_disable" ]; then
    status="[Disable Acce]"
    lightwan_video_acce_disable ${videoPortRange}
elif [ ${action} = "acce_interface_update" ]; then
    status="[Update Acce]"
    lightwan_acce_interface_update ${DefaultIf}
fi
